#! /bin/sh 
# Install openblas fev2020
# version v0.3.7 (openblas includes lapack and lapacke)
# peut etre lance avec ./InstallOpenBlas.sh 2>&1 | tee install.log 
# pour conserver une trace des log
# dans le log, les etapes importantes sont marquees par #> en debut de ligne
# donc on peut parcourir ces etapes en recherchant ^#>
#  =============================================

echo "ce fichier $(basename $0) doit etre dans le repertoire de construction"
# check if OpenBlasInstall is inside working directory
# exit if not
# 
if ! test -d OpenBlasInstall 
then
  echo "deplacer ce fichier dans le repertoire de construction" 2>&1
  echo " au dessus de OpenBlasInstall  avant de le lancer"  2>&1
  exit 1
fi

# 1) Choose (create if needed) a directory where to install the library
# and edit the file installpath.inc accordingly
# installpath.inc is included by : openblas/myMakefile
# vi OpenBlasInstall/installpath.inc 
# defines INSTALLDIR and local build flags (LOCAL_BUILD_FLAGS)
# warning : installpath.inc is also sourced in this script
. ./OpenBlasInstall/installpath.inc
echo ""
echo "repertoire d'installation :  ${INSTALLDIR}"
echo -e "options locales  ${LOCAL_BUILD_FLAGS-}\n"
# mkdir creates it if needed
mkdir -p ${INSTALLDIR}
if test $? -ne 0
then
  echo "probleme dans la creation du repertoire d'installation" 2>&1
  echo "soit INSTALLDIR = ${INSTALLDIR}"  2>&1
  exit 1
fi

# 2) Download files 
# OpenBlas from http://xianyi.github.com/OpenBLAS
# lapack95 from http://www.netlib.org/lapack95/lapack95.tgz
# blas95 from http://www.phys.ens.fr/~hare/MP025/blas95.tgz
# create directory for importing files

mkdir -p network-files
# -p flag => creates the directory if it does not exist
cd network-files
# 
# download the three archives
echo -e "\n#> debut des telechargements\n"
../OpenBlasInstall/download-tgz.sh
echo -e "\n#> fin des telechargements\n"
# from here, network is not needed anymore

# unzip the tarball in the network-files directory
tar -xvzf openblas.tgz
echo -e "\n#> fin de l'extraction des fichiers depuis l'archive\n"

# rename the output dir (default OpenBLAS*) as 'openblas' 
# and move it to the main directory
mv OpenBLAS*/ ../openblas
if test $? -ne 0
then
  echo "erreur deplacement du repertoire OpenBLAS*" >&2
  exit 2
fi
# up one level
cd ..

# 3) copy the makefiles of OpenBlasInstall into openblas

cp -f ./OpenBlasInstall/installpath.inc ./openblas
cp -f ./OpenBlasInstall/makefile.blas95 ./openblas
cp -f ./OpenBlasInstall/make.inc.lapack95 ./openblas
cp -f ./OpenBlasInstall/myMakefile ./openblas

#4) enter in openblas directory

cd openblas

# and execute successively the targets in myMakefile
# warning : use gfortran as fortran compiler

# compilation of openblas, lapack et lapacke and installation
echo -e "\n#> debut de la construction de openblas"
echo -e " ainsi que de lapack et lapacke (etre patient !)\n"
# evite les "-D" vides sauf quand on descend dans des sous-repertoires
# => pas totalement satisfaisant
#FFLAGS="" CFLAGS="" make -f myMakefile build
make -f myMakefile build
echo -e "\n#> fin de la construction de openblas\n"
make -f myMakefile install
echo -e "\n#> fin de l'installation de openblas\n"

# compilation of lapack95 and installation
echo -e "\n#> debut des compilations lapack 95\n"
make -f myMakefile lapack95
echo -e "\n#> fin des compilations lapack 95\n"
make -f myMakefile lapack95install
echo -e "\n#> fin de l'installation lapack 95\n"

# compilation of blas95 and installation
echo -e "\n#> debut des compilations blas95\n"
make -f myMakefile blas95
echo -e "\n#> fin des compilations blas95\n"
make -f myMakefile blas95install
echo -e "\n#> fin de l'installation blas95\n"

echo "Fin de l'installation d'openblas et lapack + interfaces C et f95"
exit 0
